deprecation: A library to handle automated deprecations
=======================================================

Description
-----------

A library to handle automated deprecations

License
-------

Apache 2

Upstream Contact
----------------

https://pypi.org/project/deprecation/

